@@ -95,6 +95,11 @@ sopls <- function(formula, ncomp, max_comps = min(sum(ncomp), 20), data,
   }
 #  names(X) <- colnames(mf)[-1]
   X.concat <- do.call(cbind,X)
+  # Check for missing dimnames
+  if(is.null(rownames(X.concat)))
+    rownames(X.concat) <- 1:nrow(X.concat)
+  if(is.null(colnames(X.concat)))
+    colnames(X.concat) <- 1:ncol(X.concat)
   
   y <- switch(response.type,
               continuous = Y,
